/*
 * tcpconnect.h
 *
 *  Created on: 27.02.2010
 *      Author: ed
 */

#ifndef TCPCONNECT_H_
#define TCPCONNECT_H_

class tcpconnect
{
public:
	tcpconnect();
	virtual ~tcpconnect();

protected:

	tHttpUrl * m_proxy;
	int m_conFd;

	bool _Connect(const mstring & sHostname, mstring &sErrOut);
	void _Disconnect();

private:
	tcpconnect operator=(const tcpconnect&);
	tcpconnect(const tcpconnect&);

protected:
	acfg::tHostiVec::IHookHandler *m_pConnStateObserver;
};

#endif /* TCPCONNECT_H_ */
